from random_unicode_emoji.random_unicode_emoji import random_emoji

__author__ = 'Nic Jones'
__email__ = 'nic@nicpjones.com'
__version__ = '1.0.5'
__doc__ = """
Random Unicode Emoji
====================
A simple Python package that returns random Unicode emojis.

Install
-------
Install the package:
>>> pip install random-unicode-emoji

Usage
-----
Use the package:
>>> # Import the Library
>>> from random_unicode_emoji import random_emoji
>>> # Use the Function
>>> print(random_emoji())
>>> # Return Specific Count
>>> print(random_emoji(count=3))
>>> # Use Specific Version
>>> print(random_emoji(version="15.0"))
>>> # Append Custom Emoji
>>> print(random_emoji(custom=['X.X',':D']))
>>> # All Together Now
>>> print(random_emoji(3, 15, ['X.X',':D']))

Upgrade
-------
Upgrade the package to the latest version:
>>> pip install random-unicode-emoji -U
"""



#!/usr/bin/env python3
import os
import random


def random_emoji(count=1, version="latest", custom=[]):

    try:
        version = float(version)
    except ValueError:
        pass

    # Unicode Standard Emoji from https://www.unicode.org/Public/emoji/
    # wget -q -r -np -A "emoji-test.txt" -nH --cut-dirs=1 https://www.unicode.org/Public/emoji/ && find emoji/ -type d -empty -exec rmdir {} \; 2>/dev/null

    try:
        with open(os.path.join(os.path.dirname(__file__), f"./emoji/{version}/emoji-test.txt"), 'r', encoding='utf-8') as f:
            lines = [line.split(';', 1)[0].strip().split() for line in f.readlines() if line.strip() and not line.startswith("#")]
    except FileNotFoundError:
        versions = (os.listdir(os.path.join(os.path.dirname(__file__), './emoji')))
        print(f"Unicode version \"{version}\" is not supported. The following versions are supported:\n{', '.join(versions)}")
        exit()

    unicode = []

    for line in lines:
        emoji = ""
        for octet in line:
            emoji += chr(int("0x" + octet, 16))
        unicode.append(emoji)

    emojiSet = unicode + custom
    emojis = []

    for _ in range(0, count):
        emojis.append(random.choice(emojiSet))

    return emojis



import setuptools
import re

VERSIONFILE="random_unicode_emoji/__init__.py"
getversion = re.search( r"^__version__ = ['\"]([^'\"]*)['\"]", open(VERSIONFILE, "rt").read(), re.M)
if getversion:
    new_version = getversion.group(1)
else:
    raise RuntimeError("Unable to find version string in %s." % (VERSIONFILE,))

with open("README.md", "r", encoding="utf-8") as r:
    long_description = r.read()
    long_description = re.sub("\u2B50", "star", long_description)
    long_description = re.sub("\u2764", "", long_description)

    setuptools.setup(
        name='random_unicode_emoji',
        python_requires='>=3',
        version=new_version,
        license='MIT',
        author="Nic Jones",
        author_email='nic@nicpjones.com',
        description='A simple Python package that returns random Unicode emojis. \u2764',
        long_description=long_description,
        long_description_content_type="text/markdown",
        include_package_data = True,
        packages=setuptools.find_packages(),
        url='https://github.com/NicPWNs/random-unicode-emoji-py',
        download_url ='https://github.com/NicPWNs/random-unicode-emoji-py/releases',
        keywords='random unicode emoji function',
        classifiers=[
            "Programming Language :: Python :: 3",
            "License :: OSI Approved :: MIT License",
            "Operating System :: OS Independent",
        ],
    )
